#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
#
# Cisco BGP Peer metrics plugin
#
# Author: thl-cmk[at]outlook[dot]com / thl-cmk.hopto.org
# Date  : 2017-12-26
#
# 2018-05-25: cleanup
# 2020-09-10: fixed typo FMS --> FSM (Thanks martin[dot]pechstein[at]posteo[dot]de)
#

#####################################################################################################################
#
# define units for bgp peer perfdata
#
#####################################################################################################################


#####################################################################################################################
#
# define metrics for bgp peer perfdata
#
#####################################################################################################################

metric_info['cisco_bgp_peer_acceptedprefixes'] = {
    'title': _('Prefixes accepted'),
    'help': _('number of accepted prefixes'),
    'unit': 'count',
    'color': '11/a',
}
metric_info['cisco_bgp_peer_deniedprefixes'] = {
    'title': _('Prefixes denied'),
    'unit': '1/s',
    'color': '21/a',
}
metric_info['cisco_bgp_peer_advertisedprefixes'] = {
    'title': _('Prefixes advertised'),
    'unit': '1/s',
    'color': '31/a',
}
metric_info['cisco_bgp_peer_withdrawnprefixes'] = {
    'title': _('Prefixes withdrawn'),
    'unit': '1/s',
    'color': '41/a',
}
metric_info['cisco_bgp_peer_suppressedprefixes'] = {
    'title': _('Prefixes suppressed'),
    'unit': '1/s',
    'color': '12/a',
}
metric_info['cisco_bgp_peer_inupdates'] = {
    'title': _('Updates received'),
    'unit': '1/s',
    'color': '22/a',
}
metric_info['cisco_bgp_peer_outupdates'] = {
    'title': _('Updates send'),
    'unit': '1/s',
    'color': '32/a',
}
metric_info['cisco_bgp_peer_intotalmessages'] = {
    'title': _('Total messages received'),
    'unit': '1/s',
    'color': '42/a',
}
metric_info['cisco_bgp_peer_outtotalmessages'] = {
    'title': _('Total messages send'),
    'unit': '1/s',
    'color': '13/a',
}
metric_info['cisco_bgp_peer_fsmestablishedtransitions'] = {
    'title': _('FSM transitions'),
    'unit': 'count',
    'color': '23/a',
}
metric_info['cisco_bgp_peer_fsmestablishedtime'] = {
    'title': _('FSM last change'),
    'unit': 's',
    'color': '26/a',  # 26
}
metric_info['cisco_bgp_peer_inupdateelapsedtime'] = {
    'title': _('Last update received'),
    'unit': 's',
    'color': '43/a',
}

######################################################################################################################
#
# map bgp peer perfdata to metric, not really necessary but makes sure to use the right metrics
#
######################################################################################################################

check_metrics['check_mk-cisco_bgp_peer'] = {
    'acceptedprefixes': {'name': 'cisco_bgp_peer_acceptedprefixes', },
    'deniedprefixes': {'name': 'cisco_bgp_peer_deniedprefixes', },
    'advertisedprefixes': {'name': 'cisco_bgp_peer_advertisedprefixes', },
    'withdrawnprefixes': {'name': 'cisco_bgp_peer_withdrawnprefixes', },
    'suppressedprefixes': {'name': 'cisco_bgp_peer_suppressedprefixes', },
    'inupdates': {'name': 'cisco_bgp_peer_inupdates', },
    'outupdates': {'name': 'cisco_bgp_peer_outupdates', },
    'intotalmessages': {'name': 'cisco_bgp_peer_intotalmessages', },
    'outtotalmessages': {'name': 'cisco_bgp_peer_outtotalmessages', },
    'fsmestablishedtransitions': {'name': 'cisco_bgp_peer_fsmestablishedtransitions', },
    'fsmestablishedtime': {'name': 'cisco_bgp_peer_fsmestablishedtime', },
    'inupdateelapsedtime': {'name': 'cisco_bgp_peer_inupdateelapsedtime', },
}

######################################################################################################################
#
# how to graph perdata for bgp peer
#
######################################################################################################################

graph_info.append({
    'title': _('Accepted Prefixes'),
    'metrics': [
        ('cisco_bgp_peer_acceptedprefixes', 'line'),
    ],
    'scalars': [
        ('cisco_bgp_peer_acceptedprefixes:crit', _('crit')),
        ('cisco_bgp_peer_acceptedprefixes:warn', _('warn')),
    ],
})

graph_info.append({
    'title': _('Prefixes/s'),
    'metrics': [
        ('cisco_bgp_peer_deniedprefixes', 'line'),
        ('cisco_bgp_peer_advertisedprefixes', 'line'),
        ('cisco_bgp_peer_withdrawnprefixes', 'line'),
        ('cisco_bgp_peer_suppressedprefixes', 'line'),
    ],
})


graph_info.append({
    'title': _('Updates'),
    'metrics': [
        ('cisco_bgp_peer_inupdates', 'area'),
        ('cisco_bgp_peer_outupdates', '-area'),
    ]
})

graph_info.append({
    'title': _('Total messages'),
    'metrics': [
        ('cisco_bgp_peer_intotalmessages', 'area'),
        ('cisco_bgp_peer_outtotalmessages', '-area'),
    ]
})

graph_info.append({
    'title': _('FSM transitions from/to established'),
    'metrics': [
        ('cisco_bgp_peer_fsmestablishedtransitions', 'line'),
    ],
})

graph_info.append({
    'title': _('FSM established last change'),
    'metrics': [
        ('cisco_bgp_peer_fsmestablishedtime', 'line'),
    ]
})

graph_info.append({
    'title': _('Time since last update received'),
    'metrics': [
        ('cisco_bgp_peer_inupdateelapsedtime', 'line'),
    ]
})

######################################################################################################################
#
# define perf-o-meter for bgp peer uptime + prefixes accepted/advertised
#
######################################################################################################################

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'cisco_bgp_peer_fsmestablishedtime',
        'half_value': 2592000.0,
        'exponent': 2,
    },
    {
        'type': 'linear',
        'segments': ['cisco_bgp_peer_acceptedprefixes',
                     ],
        'total': 1000000,
    }
]))
