#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-

#
# Check_MK cisco_bgp_peers WATO plugin
#
# Author: thl-cmk[at]outlook[dot]com / thl-cmk.hopto.org
# Date: 2017-12-25
#
#
#
#


cisco_bgp_peer_infotext_values = [
    ('remoteid', 'Remote router ID'),
    ('remoteas', 'Remote autonomous system'),
    ('localaddr', 'Local peer IP address'),
    ('localid', 'Local router ID'),
    ('localas', 'Local autonomous system'),
]


register_check_parameters(
    subgroup_networking,
    'cisco_bgp_peer',
    _('Cisco BGP peer'),
    Dictionary(
        help=_(''),
        elements=[
            ('minuptime',
             Integer(
                 help=_('Set the time in seconds, a peer must be up before the peer is considered sable.'
                        'If the peer uptime less then X, the check outcome is set to warning.'),
                 title=_('Minimum uptime for peer. If uptime less, set check outcome to warning. Default is 1 day.'),
                 default_value=86400,
                 allow_empty=False,
                 unit='seconds',
                 minvalue=1,
             ),
             ),
            ('useaslocalas',
             Integer(
                 help=_('Use this AS number if the SNMP Value for CISCO-BGP4-MIB::cbgpPeer2LocalAs is \'0\'.'),
                 title=_('Use AS as local AS, if SNMP cbgpPeer2LocalAs is not valid.'),
                 default_value=0,
                 allow_empty=False,
             ),
             ),
            ('htmloutput',
             FixedValue(
                 True,
                 help=_('render long output of check plugin (multiline) as HTML table. Needs \'Escape HTML codes in plugin output\' in wato --> global settings disabled'),
                 title=_('enable HTML Output for long output of check plugin (multiline)'),
                 #label=_('enable'),
             )),
            ('infotext_values',
             ListChoice(
                 title=_('Remove values from Infotext'),
                 label=_('Remove values from infotext'),
                 help=_('Select values to remove from check output.'),
                 choices=cisco_bgp_peer_infotext_values,
                 default_value=[],
             )),
            ('peer_list',
             ListOf(
                 Tuple(
                     title=('BGP Peers'),
                     elements=[
                         TextUnicode(
                             title=_('BGP Peer item name (without "Cisco BGP peer")'),
                             help=_('The configured value must match a BGP item reported by the monitored '
                                    'device. For example: "10.194.115.98 IPv4 Unicast"'),
                             allow_empty=False,
                         ),
                         TextUnicode(
                             title=_('BGP Peer Alias'),
                             help=_('You can configure an individual alias here for the BGP peer matching '
                                    'the text configured in the "BGP Peer item name" field. The alias will '
                                    'be shown in the infotext'),
                         ),
                         MonitoringState(
                             default_value=2,
                             title=_('State if not found'),
                             help=_('You can configure an individual state if the BGP peer matching the text '
                                     'configured in the "BGP Peer item name" field is not found')
                         )]),
                 add_label=_('Add BGP peer'),
                 movable=False,
                 title=_('BGP peer specific configuration'),
             )),

        ],
    ),
    TextAscii(title=_('Cisco BGP peer')),
    match_type='dict',
)
